import { defineStore } from 'pinia'
import type { Character } from '@/types'
import config from '@/config'

export const useZoneStore = defineStore('zone', {
  state: () => ({
    tiles: [] as number[][],
    characters: [] as Character[]
  }),
  actions: {
    setTiles(tiles: number[][]) {
      this.tiles = tiles
    },
    setCharacters(characters: Character[]) {
      this.characters = characters
    },
    addCharacter(character: Character) {
      this.characters.push(character)
    },
    updateCharacter(character: Character) {
      const index = this.characters.findIndex((c) => c.id === character.id)
      if (index === -1) return
      this.characters[index] = character
    },
    removeCharacter(character: Character) {
      this.characters = this.characters.filter((c: Character) => c.id !== character.id)
    },
    reset() {
      this.tiles = []
      this.characters = []
    }
  }
})
