import { defineStore } from 'pinia'

export const useZoneEditorStore = defineStore('zoneEditor', {
  state: () => ({
    active: true,
    name: '',
    width: 10,
    height: 10,
    tiles: [] as number[][],
    walls: [] as number[][],
    decorations: [] as number[][],
    tool: 'move',
    drawMode: 'wall',
    selectedTile: null,
    selectedWall: null,
    selectedDecoration: null,
    isSettingsModalShown: false
  }),
  actions: {
    toggleActive() {
      this.active = !this.active
    },
    setName(name: string) {
      this.name = name
    },
    setWidth(width: number) {
      this.width = width
    },
    setHeight(height: number) {
      this.height = height
    },
    setTiles(tiles: number[][]) {
      this.tiles = tiles
    },
    updateTile(x: number, y: number, tile: number) {
      this.tiles[y][x] = tile
    },
    setWalls(walls: number[][]) {
      this.walls = walls
    },
    updateWall(x: number, y: number, wall: number) {
      this.walls[y][x] = wall
    },
    setDecorations(decorations: number[][]) {
      this.decorations = decorations
    },
    updateDecoration(x: number, y: number, decoration: number) {
      this.decorations[y][x] = decoration
    },
    setTool(tool: string) {
      this.tool = tool
    },
    setDrawMode(mode: string) {
      this.drawMode = mode
    },
    setSelectedTile(tile: any) {
      this.selectedTile = tile
    },
    setSelectedWall(wall: any) {
      this.selectedWall = wall
    },
    setSelectedDecoration(decoration: any) {
      this.selectedDecoration = decoration
    },
    toggleSettingsModal() {
      this.isSettingsModalShown = !this.isSettingsModalShown
    },
    reset() {
      this.name = ''
      this.width = 10
      this.height = 10
      this.tiles = []
      this.tool = 'move'
      this.drawMode = 'wall'
      this.selectedTile = null
      this.selectedWall = null
      this.selectedDecoration = null
      this.isSettingsModalShown = false
    }
  }
})

/**
 * Resources:
 * https://www.html5gamedevs.com/topic/21908-phaser-is-there-any-tutorial-on-how-to-do-an-isometric-game/
 * http://murdochcarpenter.com/isometric-starling-part-i/
 */